discovery

package
v0.0.0-...-1367a92 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package discovery adds relevant library functions for working with workloads discovered via the discover-workload library. https://github.com/opdev/discover-workload.

Index

Constants

This section is empty.

Variables

var (
	ErrDuplicateComponentName           = errors.New("duplicate component name")
	ErrNoImagesDiscovered               = errors.New("no images found in discovery manifest")
	ErrCountingContainerNameOccurrences = errors.New("failed counting container names")
	ErrNoContainers                     = errors.New("no containers in entry for image")
)

Functions

func ComponentsFromDiscoveryManifest

func ComponentsFromDiscoveryManifest(manifest discovery.Manifest) ([]*resource.Component, error)

ComponentsFromDiscoveryManifest converts discovered workloads into Component declarations. DiscoveredImages are treated as container components. The specifics of the container component declaration are assumed, and left to the user to change before use.

Types

This section is empty.

Jump to